@@ -31,7 +31,7 @@ bool MouseTracker::eventFilter(QObject *watched, QEvent *event)
     switch (type) {
     case QEvent::MouseMove: {
         const auto mouseEvent = static_cast<QMouseEvent *>(event);
-        m_lastMousePos = mouseEvent->windowPos();
+        m_lastMousePos = mouseEvent->scenePosition();
         Q_EMIT mousePositionChanged(m_lastMousePos);
         break;
     }
@@ -47,3 +47,5 @@ bool MouseTracker::eventFilter(QObject *watched, QEvent *event)
 
     return QObject::eventFilter(watched, event);
 }
+
+#include "moc_mousetracker.cpp"
