@@ -6,7 +6,9 @@
 #include <KContacts/Address>
 #include <QAbstractListModel>
 
-class AddressModel : public QAbstractListModel
+#include "merkuro_contact_export.h"
+
+class MERKURO_CONTACT_EXPORT AddressModel : public QAbstractListModel
 {
     Q_OBJECT
 
