@@ -7,10 +7,12 @@
 #include <Akonadi/Item>
 #include <KMime/Message>
 #include <QObject>
+#include <qqmlregistration.h>
 
 class MessageLoader : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_PROPERTY(Akonadi::Item item READ item WRITE setItem NOTIFY itemChanged)
     Q_PROPERTY(KMime::Message::Ptr message READ message NOTIFY messageChanged)
 
@@ -19,7 +21,7 @@ public:
 
     [[nodiscard]] Akonadi::Item item() const;
     void setItem(const Akonadi::Item &item);
-    KMime::Message::Ptr message() const;
+    [[nodiscard]] KMime::Message::Ptr message() const;
 
 Q_SIGNALS:
     void itemChanged();
